# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountAlerts(BaseModel):
    count_alerts: Optional["CountAlertsCountAlerts"] = Field(alias="countAlerts")


class CountAlertsCountAlerts(BaseModel):
    count: Optional[Any]


CountAlerts.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateProject(BaseModel):
    update_project: Optional["UpdateProjectUpdateProject"] = Field(
        alias="updateProject"
    )


class UpdateProjectUpdateProject(BaseModel):
    id: str
    name: str


UpdateProject.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class CreateObservation(BaseModel):
    create_observation: Optional["CreateObservationCreateObservation"] = Field(
        alias="createObservation"
    )


class CreateObservationCreateObservation(BaseModel):
    id: str
    state: EntityState


CreateObservation.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    AuthenticationServiceTypes,
    ConnectorTypes,
    EntityState,
    IntegrationServiceTypes,
    UserTypes,
)


class QueryUsers(BaseModel):
    users: Optional["QueryUsersUsers"]


class QueryUsersUsers(BaseModel):
    results: Optional[List["QueryUsersUsersResults"]]


class QueryUsersUsersResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "QueryUsersUsersResultsOwner"
    state: EntityState
    type: Optional[UserTypes]
    identifier: str
    description: Optional[str]
    connectors: Optional[List[Optional["QueryUsersUsersResultsConnectors"]]]


class QueryUsersUsersResultsOwner(BaseModel):
    id: str


class QueryUsersUsersResultsConnectors(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ConnectorTypes]
    authentication: Optional["QueryUsersUsersResultsConnectorsAuthentication"]
    integration: Optional["QueryUsersUsersResultsConnectorsIntegration"]


class QueryUsersUsersResultsConnectorsAuthentication(BaseModel):
    type: AuthenticationServiceTypes
    microsoft: Optional["QueryUsersUsersResultsConnectorsAuthenticationMicrosoft"]
    google: Optional["QueryUsersUsersResultsConnectorsAuthenticationGoogle"]


class QueryUsersUsersResultsConnectorsAuthenticationMicrosoft(BaseModel):
    tenant_id: str = Field(alias="tenantId")
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")


class QueryUsersUsersResultsConnectorsAuthenticationGoogle(BaseModel):
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")


class QueryUsersUsersResultsConnectorsIntegration(BaseModel):
    type: IntegrationServiceTypes
    uri: Optional[str]
    slack: Optional["QueryUsersUsersResultsConnectorsIntegrationSlack"]
    email: Optional["QueryUsersUsersResultsConnectorsIntegrationEmail"]
    twitter: Optional["QueryUsersUsersResultsConnectorsIntegrationTwitter"]


class QueryUsersUsersResultsConnectorsIntegrationSlack(BaseModel):
    token: str
    channel: str


class QueryUsersUsersResultsConnectorsIntegrationEmail(BaseModel):
    from_: str = Field(alias="from")
    subject: str
    to: List[str]


class QueryUsersUsersResultsConnectorsIntegrationTwitter(BaseModel):
    consumer_key: str = Field(alias="consumerKey")
    consumer_secret: str = Field(alias="consumerSecret")
    access_token_key: str = Field(alias="accessTokenKey")
    access_token_secret: str = Field(alias="accessTokenSecret")


QueryUsers.model_rebuild()
QueryUsersUsers.model_rebuild()
QueryUsersUsersResults.model_rebuild()
QueryUsersUsersResultsConnectors.model_rebuild()
QueryUsersUsersResultsConnectorsAuthentication.model_rebuild()
QueryUsersUsersResultsConnectorsIntegration.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetEvent(BaseModel):
    event: Optional["GetEventEvent"]


class GetEventEvent(BaseModel):
    id: str
    name: str
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    creation_date: Any = Field(alias="creationDate")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    relevance: Optional[float]
    address: Optional["GetEventEventAddress"]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    availability_start_date: Optional[Any] = Field(alias="availabilityStartDate")
    availability_end_date: Optional[Any] = Field(alias="availabilityEndDate")
    price: Optional[Any]
    min_price: Optional[Any] = Field(alias="minPrice")
    max_price: Optional[Any] = Field(alias="maxPrice")
    price_currency: Optional[str] = Field(alias="priceCurrency")
    is_accessible_for_free: Optional[bool] = Field(alias="isAccessibleForFree")
    typical_age_range: Optional[str] = Field(alias="typicalAgeRange")


class GetEventEventAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


GetEvent.model_rebuild()
GetEventEvent.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DisableUser(BaseModel):
    disable_user: Optional["DisableUserDisableUser"] = Field(alias="disableUser")


class DisableUserDisableUser(BaseModel):
    id: str
    state: EntityState


DisableUser.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalDrugClass(BaseModel):
    update_medical_drug_class: Optional[
        "UpdateMedicalDrugClassUpdateMedicalDrugClass"
    ] = Field(alias="updateMedicalDrugClass")


class UpdateMedicalDrugClassUpdateMedicalDrugClass(BaseModel):
    id: str
    name: str


UpdateMedicalDrugClass.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ContentFacetTypes, FacetValueTypes, ObservableTypes


class QueryContentsFacets(BaseModel):
    contents: Optional["QueryContentsFacetsContents"]


class QueryContentsFacetsContents(BaseModel):
    facets: Optional[List[Optional["QueryContentsFacetsContentsFacets"]]]


class QueryContentsFacetsContentsFacets(BaseModel):
    facet: Optional[ContentFacetTypes]
    count: Optional[Any]
    type: Optional[FacetValueTypes]
    value: Optional[str]
    range: Optional["QueryContentsFacetsContentsFacetsRange"]
    observable: Optional["QueryContentsFacetsContentsFacetsObservable"]


class QueryContentsFacetsContentsFacetsRange(BaseModel):
    from_: Optional[str] = Field(alias="from")
    to: Optional[str]


class QueryContentsFacetsContentsFacetsObservable(BaseModel):
    type: Optional[ObservableTypes]
    observable: Optional["QueryContentsFacetsContentsFacetsObservableObservable"]


class QueryContentsFacetsContentsFacetsObservableObservable(BaseModel):
    id: str
    name: Optional[str]


QueryContentsFacets.model_rebuild()
QueryContentsFacetsContents.model_rebuild()
QueryContentsFacetsContentsFacets.model_rebuild()
QueryContentsFacetsContentsFacetsObservable.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryMedicalTherapies(BaseModel):
    medical_therapies: Optional["QueryMedicalTherapiesMedicalTherapies"] = Field(
        alias="medicalTherapies"
    )


class QueryMedicalTherapiesMedicalTherapies(BaseModel):
    results: Optional[List[Optional["QueryMedicalTherapiesMedicalTherapiesResults"]]]


class QueryMedicalTherapiesMedicalTherapiesResults(BaseModel):
    id: str
    name: str
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    creation_date: Any = Field(alias="creationDate")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    relevance: Optional[float]


QueryMedicalTherapies.model_rebuild()
QueryMedicalTherapiesMedicalTherapies.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class WorkflowExists(BaseModel):
    workflow_exists: Optional["WorkflowExistsWorkflowExists"] = Field(
        alias="workflowExists"
    )


class WorkflowExistsWorkflowExists(BaseModel):
    result: Optional[bool]


WorkflowExists.model_rebuild()
